==> amarok_2.9.0.orig.tar.xz: amarok-2.9.0/src/statsyncing/ProviderFactory.cpp <==
/****************************************************************************************
 * Copyright (c) 2013 Konrad Zemek <konrad.zemek@gmail.com>                             *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#include "ProviderFactory.h"

#include "Provider.h"

using namespace StatSyncing;

ProviderFactory::ProviderFactory( QObject *parent, const QVariantList &args )
    : Plugins::PluginFactory( parent, args )
{
}

ProviderFactory::~ProviderFactory()
{
}

QString
ProviderFactory::description() const
{
    return QString();
}

==> amarok_3.3.1.orig.tar.xz: amarok-3.3.1/src/statsyncing/ProviderFactory.cpp <==
/****************************************************************************************
 * Copyright (c) 2013 Konrad Zemek <konrad.zemek@gmail.com>                             *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#include "ProviderFactory.h"

#include "Provider.h"

using namespace StatSyncing;

ProviderFactory::ProviderFactory()
    : Plugins::PluginFactory()
{
}

ProviderFactory::~ProviderFactory()
{
}

QString
ProviderFactory::description() const
{
    return QString();
}
